package com.google.common.collect;

import com.google.common.annotations.GwtCompatible;
import com.google.common.annotations.GwtIncompatible;
import com.google.common.base.Preconditions;
import com.google.common.collect.ImmutableBiMap;
import com.google.common.collect.ImmutableMap;
import com.google.common.collect.ImmutableRangeMap;
import com.google.common.collect.ImmutableSortedMap;
import com.google.common.collect.ImmutableSortedSet;
import java.util.Comparator;
import java.util.function.BiConsumer;
import java.util.function.Function;
import java.util.function.Supplier;
import java.util.stream.Collector;
@GwtCompatible
/* loaded from: classes.dex */
final class CollectCollectors {
    private static final Collector<Object, ?, ImmutableList<Object>> TO_IMMUTABLE_LIST = Collector.of($$Lambda$DfydzOF3bxBxHq3iqs49ZgMLUs.INSTANCE, $$Lambda$QvyaiL_hYayIQFE2St24To5wZE.INSTANCE, $$Lambda$Qx83BY6lz6Jpv1dd6polKavxmK8.INSTANCE, $$Lambda$B6qMqDjsj2i6zaZiqfU9Ziu4KU.INSTANCE, new Collector.Characteristics[0]);
    private static final Collector<Object, ?, ImmutableSet<Object>> TO_IMMUTABLE_SET = Collector.of($$Lambda$D2fWAlgZqZKOlZH1XayB5NNFYg.INSTANCE, $$Lambda$IdVJip9QnNnOjsjbknfdGci9RiE.INSTANCE, $$Lambda$wUAReslCQiBwCn6kktgOARAFWY.INSTANCE, $$Lambda$T_uso8JlwUHIict0GBhQKPJhLA.INSTANCE, new Collector.Characteristics[0]);
    @GwtIncompatible
    private static final Collector<Range<Comparable>, ?, ImmutableRangeSet<Comparable>> TO_IMMUTABLE_RANGE_SET = Collector.of($$Lambda$qYrmkTOaUrLYeL7EApXANHaSYdI.INSTANCE, $$Lambda$lowwVYyQOaWraSEhFKduT64LPV0.INSTANCE, $$Lambda$7Mxhy81NAiwcDk9tE05wrS15B5g.INSTANCE, $$Lambda$3snfJOhsHXrS4Qvlzt9iufmIkY8.INSTANCE, new Collector.Characteristics[0]);

    CollectCollectors() {
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static <T, K, V> Collector<T, ?, ImmutableBiMap<K, V>> toImmutableBiMap(final Function<? super T, ? extends K> function, final Function<? super T, ? extends V> function2) {
        Preconditions.checkNotNull(function);
        Preconditions.checkNotNull(function2);
        return Collector.of($$Lambda$_m_t76O2vKrvy2DwB7sQvYoUFCw.INSTANCE, new BiConsumer() { // from class: com.google.common.collect.-$$Lambda$CollectCollectors$HMw9mDrSvkUs_smMpKcOhX6haxs
            @Override // java.util.function.BiConsumer
            public final void accept(Object obj, Object obj2) {
                ((ImmutableBiMap.Builder) obj).put((ImmutableBiMap.Builder) function.apply(obj2), (ImmutableBiMap.Builder) function2.apply(obj2));
            }
        }, $$Lambda$QPuM9iKoW1PCf2mQzuKDfsTjICw.INSTANCE, $$Lambda$XhUs_LRHe4OdfH7q5ERshr3mO8.INSTANCE, new Collector.Characteristics[0]);
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static <E> Collector<E, ?, ImmutableList<E>> toImmutableList() {
        return (Collector<E, ?, ImmutableList<E>>) TO_IMMUTABLE_LIST;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static <T, K, V> Collector<T, ?, ImmutableMap<K, V>> toImmutableMap(final Function<? super T, ? extends K> function, final Function<? super T, ? extends V> function2) {
        Preconditions.checkNotNull(function);
        Preconditions.checkNotNull(function2);
        return Collector.of($$Lambda$2DoWASnF6dZ7iLd1Bp9mMxtgx34.INSTANCE, new BiConsumer() { // from class: com.google.common.collect.-$$Lambda$CollectCollectors$QEt2k0TxRNpKjocJNjSlM4nzwzg
            @Override // java.util.function.BiConsumer
            public final void accept(Object obj, Object obj2) {
                ((ImmutableMap.Builder) obj).put(function.apply(obj2), function2.apply(obj2));
            }
        }, $$Lambda$iMl639MbEQfK2Uwz4dSjiDOdD0Y.INSTANCE, $$Lambda$JNR12gyt_ZEeeKFrcwlQXfJuBo.INSTANCE, new Collector.Characteristics[0]);
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static <E> Collector<E, ?, ImmutableSet<E>> toImmutableSet() {
        return (Collector<E, ?, ImmutableSet<E>>) TO_IMMUTABLE_SET;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static <T, K, V> Collector<T, ?, ImmutableSortedMap<K, V>> toImmutableSortedMap(final Comparator<? super K> comparator, final Function<? super T, ? extends K> function, final Function<? super T, ? extends V> function2) {
        Preconditions.checkNotNull(comparator);
        Preconditions.checkNotNull(function);
        Preconditions.checkNotNull(function2);
        return Collector.of(new Supplier() { // from class: com.google.common.collect.-$$Lambda$CollectCollectors$JbNzTVqa2YS9FTms4CBu4SjH7ak
            @Override // java.util.function.Supplier
            public final Object get() {
                return CollectCollectors.lambda$toImmutableSortedMap$2(comparator);
            }
        }, new BiConsumer() { // from class: com.google.common.collect.-$$Lambda$CollectCollectors$LRJvFLvkG13RJZ8bFXav4HMCTMQ
            @Override // java.util.function.BiConsumer
            public final void accept(Object obj, Object obj2) {
                ((ImmutableSortedMap.Builder) obj).put((ImmutableSortedMap.Builder) function.apply(obj2), (ImmutableSortedMap.Builder) function2.apply(obj2));
            }
        }, $$Lambda$xRTACJ_W0N2wW_qcPf4oUEy47wM.INSTANCE, $$Lambda$siK1rvzVZhWHDX4C7n3RSZYbQfs.INSTANCE, Collector.Characteristics.UNORDERED);
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static /* synthetic */ ImmutableSortedMap.Builder lambda$toImmutableSortedMap$2(Comparator comparator) {
        return new ImmutableSortedMap.Builder(comparator);
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static <E> Collector<E, ?, ImmutableSortedSet<E>> toImmutableSortedSet(final Comparator<? super E> comparator) {
        Preconditions.checkNotNull(comparator);
        return Collector.of(new Supplier() { // from class: com.google.common.collect.-$$Lambda$CollectCollectors$hEyPbqEvvnuK__OqWC8HpCfj_fE
            @Override // java.util.function.Supplier
            public final Object get() {
                return CollectCollectors.lambda$toImmutableSortedSet$4(comparator);
            }
        }, $$Lambda$FLuZpkQmNg7JOBdGkuDvpE1c7wY.INSTANCE, $$Lambda$Gb0cLXsnGYbZK6C3LsaZrtl7k8.INSTANCE, $$Lambda$HYy5QkqepjzFGDSicdDzvjxFZSk.INSTANCE, new Collector.Characteristics[0]);
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static /* synthetic */ ImmutableSortedSet.Builder lambda$toImmutableSortedSet$4(Comparator comparator) {
        return new ImmutableSortedSet.Builder(comparator);
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    @GwtIncompatible
    public static <E extends Comparable<? super E>> Collector<Range<E>, ?, ImmutableRangeSet<E>> toImmutableRangeSet() {
        return (Collector<Range<E>, ?, ImmutableRangeSet<E>>) TO_IMMUTABLE_RANGE_SET;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    @GwtIncompatible
    public static <T, K extends Comparable<? super K>, V> Collector<T, ?, ImmutableRangeMap<K, V>> toImmutableRangeMap(final Function<? super T, Range<K>> function, final Function<? super T, ? extends V> function2) {
        Preconditions.checkNotNull(function);
        Preconditions.checkNotNull(function2);
        return Collector.of($$Lambda$gysTBkYkLoQ6CU7u_E1e7mz2Fg.INSTANCE, new BiConsumer() { // from class: com.google.common.collect.-$$Lambda$CollectCollectors$65HCb4TFteqa_fnqC20JyjqXnWQ
            @Override // java.util.function.BiConsumer
            public final void accept(Object obj, Object obj2) {
                ((ImmutableRangeMap.Builder) obj).put((Range) function.apply(obj2), function2.apply(obj2));
            }
        }, $$Lambda$zFfqyVq5T798wGUZivKwgD4lls.INSTANCE, $$Lambda$k2Nywlv8zwjiSiBaJUxSurcGA.INSTANCE, new Collector.Characteristics[0]);
    }
}
