package com.google.common.collect;

import com.google.common.annotations.Beta;
import com.google.common.annotations.GwtCompatible;
import com.google.common.base.Preconditions;
import java.util.ArrayList;
import java.util.List;
import java.util.NoSuchElementException;
import java.util.Optional;
import java.util.stream.Collector;
import org.checkerframework.checker.nullness.compatqual.NullableDecl;
@Beta
@GwtCompatible
/* loaded from: classes.dex */
public final class MoreCollectors {
    private static final Collector<Object, ?, Optional<Object>> TO_OPTIONAL = Collector.of($$Lambda$AW8d5rjde7n52sHHlfKGLys6o4.INSTANCE, $$Lambda$OugZ7uzX1ge93a2UFbU199Ga9uI.INSTANCE, $$Lambda$T3Z3qL6s2UgnlIibFIHZE8hnQd8.INSTANCE, $$Lambda$qKNWqC3OxvkO7x9RxwopFUoEg4.INSTANCE, Collector.Characteristics.UNORDERED);
    private static final Object NULL_PLACEHOLDER = new Object();
    private static final Collector<Object, ?, Object> ONLY_ELEMENT = Collector.of($$Lambda$AW8d5rjde7n52sHHlfKGLys6o4.INSTANCE, $$Lambda$MoreCollectors$oN3vFXc6_LKZJQOgj9PeBSrbA4g.INSTANCE, $$Lambda$T3Z3qL6s2UgnlIibFIHZE8hnQd8.INSTANCE, $$Lambda$MoreCollectors$A6KiO1a0N4DLe0rKqSWOUITsXo.INSTANCE, Collector.Characteristics.UNORDERED);

    public static <T> Collector<T, ?, Optional<T>> toOptional() {
        return (Collector<T, ?, Optional<T>>) TO_OPTIONAL;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static /* synthetic */ void lambda$static$0(ToOptionalState toOptionalState, Object obj) {
        if (obj == null) {
            obj = NULL_PLACEHOLDER;
        }
        toOptionalState.add(obj);
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static /* synthetic */ Object lambda$static$1(ToOptionalState toOptionalState) {
        Object element = toOptionalState.getElement();
        if (element == NULL_PLACEHOLDER) {
            return null;
        }
        return element;
    }

    public static <T> Collector<T, ?, T> onlyElement() {
        return (Collector<T, ?, T>) ONLY_ELEMENT;
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes.dex */
    public static final class ToOptionalState {
        static final int MAX_EXTRAS = 4;
        @NullableDecl
        Object element = null;
        @NullableDecl
        List<Object> extras = null;

        IllegalArgumentException multiples(boolean z) {
            StringBuilder sb = new StringBuilder();
            sb.append("expected one element but was: <");
            sb.append(this.element);
            for (Object obj : this.extras) {
                sb.append(", ");
                sb.append(obj);
            }
            if (z) {
                sb.append(", ...");
            }
            sb.append('>');
            throw new IllegalArgumentException(sb.toString());
        }

        /* JADX INFO: Access modifiers changed from: package-private */
        public void add(Object obj) {
            Preconditions.checkNotNull(obj);
            if (this.element == null) {
                this.element = obj;
            } else if (this.extras == null) {
                this.extras = new ArrayList(4);
                this.extras.add(obj);
            } else if (this.extras.size() < 4) {
                this.extras.add(obj);
            } else {
                throw multiples(true);
            }
        }

        /* JADX INFO: Access modifiers changed from: package-private */
        public ToOptionalState combine(ToOptionalState toOptionalState) {
            if (this.element == null) {
                return toOptionalState;
            }
            if (toOptionalState.element == null) {
                return this;
            }
            if (this.extras == null) {
                this.extras = new ArrayList();
            }
            this.extras.add(toOptionalState.element);
            if (toOptionalState.extras != null) {
                this.extras.addAll(toOptionalState.extras);
            }
            if (this.extras.size() <= 4) {
                return this;
            }
            this.extras.subList(4, this.extras.size()).clear();
            throw multiples(true);
        }

        /* JADX INFO: Access modifiers changed from: package-private */
        public Optional<Object> getOptional() {
            if (this.extras == null) {
                return Optional.ofNullable(this.element);
            }
            throw multiples(false);
        }

        Object getElement() {
            if (this.element == null) {
                throw new NoSuchElementException();
            }
            if (this.extras == null) {
                return this.element;
            }
            throw multiples(false);
        }
    }

    private MoreCollectors() {
    }
}
