package com.google.common.collect;

import com.google.common.annotations.Beta;
import com.google.common.annotations.GwtCompatible;
import com.google.common.base.Optional;
import com.google.common.base.Preconditions;
import com.google.common.collect.ImmutableList;
import com.google.common.collect.Streams;
import com.google.common.math.LongMath;
import java.util.ArrayDeque;
import java.util.Collection;
import java.util.Iterator;
import java.util.OptionalDouble;
import java.util.OptionalInt;
import java.util.OptionalLong;
import java.util.PrimitiveIterator;
import java.util.Spliterator;
import java.util.Spliterators;
import java.util.function.BiConsumer;
import java.util.function.BiFunction;
import java.util.function.Consumer;
import java.util.function.DoubleConsumer;
import java.util.function.IntConsumer;
import java.util.function.LongConsumer;
import java.util.stream.DoubleStream;
import java.util.stream.IntStream;
import java.util.stream.LongStream;
import java.util.stream.Stream;
import java.util.stream.StreamSupport;
import org.checkerframework.checker.nullness.compatqual.NullableDecl;
@Beta
@GwtCompatible
/* loaded from: classes.dex */
public final class Streams {

    @Beta
    /* loaded from: classes.dex */
    public interface DoubleFunctionWithIndex<R> {
        R apply(double d, long j);
    }

    @Beta
    /* loaded from: classes.dex */
    public interface FunctionWithIndex<T, R> {
        R apply(T t, long j);
    }

    @Beta
    /* loaded from: classes.dex */
    public interface IntFunctionWithIndex<R> {
        R apply(int i, long j);
    }

    @Beta
    /* loaded from: classes.dex */
    public interface LongFunctionWithIndex<R> {
        R apply(long j, long j2);
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static /* synthetic */ Spliterator lambda$concat$0(Spliterator spliterator) {
        return spliterator;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static /* synthetic */ IntStream lambda$concat$2(IntStream intStream) {
        return intStream;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static /* synthetic */ LongStream lambda$concat$3(LongStream longStream) {
        return longStream;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static /* synthetic */ DoubleStream lambda$concat$4(DoubleStream doubleStream) {
        return doubleStream;
    }

    public static <T> Stream<T> stream(Iterable<T> iterable) {
        if (iterable instanceof Collection) {
            return ((Collection) iterable).stream();
        }
        return StreamSupport.stream(iterable.spliterator(), false);
    }

    @Deprecated
    public static <T> Stream<T> stream(Collection<T> collection) {
        return collection.stream();
    }

    public static <T> Stream<T> stream(Iterator<T> it) {
        return StreamSupport.stream(Spliterators.spliteratorUnknownSize(it, 0), false);
    }

    public static <T> Stream<T> stream(Optional<T> optional) {
        return optional.isPresent() ? Stream.of(optional.get()) : Stream.of(new Object[0]);
    }

    public static <T> Stream<T> stream(java.util.Optional<T> optional) {
        return optional.isPresent() ? Stream.of(optional.get()) : Stream.of(new Object[0]);
    }

    public static IntStream stream(OptionalInt optionalInt) {
        return optionalInt.isPresent() ? IntStream.of(optionalInt.getAsInt()) : IntStream.empty();
    }

    public static LongStream stream(OptionalLong optionalLong) {
        return optionalLong.isPresent() ? LongStream.of(optionalLong.getAsLong()) : LongStream.empty();
    }

    public static DoubleStream stream(OptionalDouble optionalDouble) {
        return optionalDouble.isPresent() ? DoubleStream.of(optionalDouble.getAsDouble()) : DoubleStream.empty();
    }

    @SafeVarargs
    public static <T> Stream<T> concat(final Stream<? extends T>... streamArr) {
        ImmutableList.Builder builder = new ImmutableList.Builder(streamArr.length);
        long j = 0;
        boolean z = false;
        int i = 336;
        for (Stream<? extends T> stream : streamArr) {
            z |= stream.isParallel();
            Spliterator<? extends T> spliterator = stream.spliterator();
            builder.add((ImmutableList.Builder) spliterator);
            i &= spliterator.characteristics();
            j = LongMath.saturatedAdd(j, spliterator.estimateSize());
        }
        return (Stream) StreamSupport.stream(CollectSpliterators.flatMap(builder.build().spliterator(), $$Lambda$Streams$pg5lCmobtfFNBTlUWWOJMXOdCHI.INSTANCE, i, j), z).onClose(new Runnable() { // from class: com.google.common.collect.-$$Lambda$Streams$-fJ3BDxCKVPJ_jbG_129irN7jjs
            @Override // java.lang.Runnable
            public final void run() {
                Streams.lambda$concat$1(streamArr);
            }
        });
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static /* synthetic */ void lambda$concat$1(Stream[] streamArr) {
        for (Stream stream : streamArr) {
            stream.close();
        }
    }

    public static IntStream concat(IntStream... intStreamArr) {
        return Stream.of((Object[]) intStreamArr).flatMapToInt($$Lambda$Streams$0xkxYg8VXW7gpz14ijnFhxnO6gU.INSTANCE);
    }

    public static LongStream concat(LongStream... longStreamArr) {
        return Stream.of((Object[]) longStreamArr).flatMapToLong($$Lambda$Streams$tiE5G6lEAonnbjIOY2PUJGlhdW0.INSTANCE);
    }

    public static DoubleStream concat(DoubleStream... doubleStreamArr) {
        return Stream.of((Object[]) doubleStreamArr).flatMapToDouble($$Lambda$Streams$QGYDOKLSvNnELoNCzsUp2eCgfd8.INSTANCE);
    }

    public static <A, B, R> Stream<R> zip(Stream<A> stream, Stream<B> stream2, final BiFunction<? super A, ? super B, R> biFunction) {
        Preconditions.checkNotNull(stream);
        Preconditions.checkNotNull(stream2);
        Preconditions.checkNotNull(biFunction);
        boolean z = stream.isParallel() || stream2.isParallel();
        Spliterator<A> spliterator = stream.spliterator();
        Spliterator<B> spliterator2 = stream2.spliterator();
        final Iterator it = Spliterators.iterator(spliterator);
        final Iterator it2 = Spliterators.iterator(spliterator2);
        Stream stream3 = StreamSupport.stream(new Spliterators.AbstractSpliterator<R>(Math.min(spliterator.estimateSize(), spliterator2.estimateSize()), spliterator.characteristics() & spliterator2.characteristics() & 80) { // from class: com.google.common.collect.Streams.1
            @Override // java.util.Spliterator
            public boolean tryAdvance(Consumer<? super R> consumer) {
                if (it.hasNext() && it2.hasNext()) {
                    consumer.accept(biFunction.apply(it.next(), it2.next()));
                    return true;
                }
                return false;
            }
        }, z);
        stream.getClass();
        stream2.getClass();
        return (Stream) ((Stream) stream3.onClose(new $$Lambda$Zs9InZa8XuPuxDobaApOmS3136M(stream))).onClose(new $$Lambda$Zs9InZa8XuPuxDobaApOmS3136M(stream2));
    }

    public static <A, B> void forEachPair(Stream<A> stream, Stream<B> stream2, final BiConsumer<? super A, ? super B> biConsumer) {
        Preconditions.checkNotNull(biConsumer);
        if (stream.isParallel() || stream2.isParallel()) {
            zip(stream, stream2, $$Lambda$honSnvIdwT3TeQ412WPHBfMqYLk.INSTANCE).forEach(new Consumer() { // from class: com.google.common.collect.-$$Lambda$Streams$z5bnm_D9PNFiwKslaS0fGzva7bU
                @Override // java.util.function.Consumer
                public final void accept(Object obj) {
                    biConsumer.accept(r2.a, ((Streams.TemporaryPair) obj).b);
                }
            });
            return;
        }
        Iterator<A> it = stream.iterator();
        Iterator<B> it2 = stream2.iterator();
        while (it.hasNext() && it2.hasNext()) {
            biConsumer.accept(it.next(), it2.next());
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes.dex */
    public static class TemporaryPair<A, B> {
        final A a;
        final B b;

        /* JADX INFO: Access modifiers changed from: package-private */
        public TemporaryPair(A a, B b) {
            this.a = a;
            this.b = b;
        }
    }

    public static <T, R> Stream<R> mapWithIndex(Stream<T> stream, final FunctionWithIndex<? super T, ? extends R> functionWithIndex) {
        Preconditions.checkNotNull(stream);
        Preconditions.checkNotNull(functionWithIndex);
        boolean isParallel = stream.isParallel();
        Spliterator<T> spliterator = stream.spliterator();
        if (!spliterator.hasCharacteristics(16384)) {
            final Iterator it = Spliterators.iterator(spliterator);
            Stream stream2 = StreamSupport.stream(new Spliterators.AbstractSpliterator<R>(spliterator.estimateSize(), spliterator.characteristics() & 80) { // from class: com.google.common.collect.Streams.2
                long index = 0;

                @Override // java.util.Spliterator
                public boolean tryAdvance(Consumer<? super R> consumer) {
                    if (it.hasNext()) {
                        FunctionWithIndex functionWithIndex2 = functionWithIndex;
                        Object next = it.next();
                        long j = this.index;
                        this.index = 1 + j;
                        consumer.accept(functionWithIndex2.apply(next, j));
                        return true;
                    }
                    return false;
                }
            }, isParallel);
            stream.getClass();
            return (Stream) stream2.onClose(new $$Lambda$Zs9InZa8XuPuxDobaApOmS3136M(stream));
        }
        Stream stream3 = StreamSupport.stream(new C1Splitr(spliterator, 0L, functionWithIndex), isParallel);
        stream.getClass();
        return (Stream) stream3.onClose(new $$Lambda$Zs9InZa8XuPuxDobaApOmS3136M(stream));
    }

    /* renamed from: com.google.common.collect.Streams$1Splitr  reason: invalid class name */
    /* loaded from: classes.dex */
    class C1Splitr extends MapWithIndexSpliterator<Spliterator<T>, R, C1Splitr> implements Consumer<T> {
        @NullableDecl
        T holder;
        final /* synthetic */ FunctionWithIndex val$function;

        /* JADX WARN: 'super' call moved to the top of the method (can break code semantics) */
        /* JADX WARN: Multi-variable type inference failed */
        /* JADX WARN: Not initialized variable reg: 4, insn: 0x0000: IPUT  (r4 I:com.google.common.collect.Streams$FunctionWithIndex), (r0 I:com.google.common.collect.Streams$1Splitr) com.google.common.collect.Streams.1Splitr.val$function com.google.common.collect.Streams$FunctionWithIndex, block:B:2:0x0000 */
        C1Splitr(Spliterator spliterator, Spliterator<T> spliterator2, long j) {
            super(spliterator, spliterator2);
            FunctionWithIndex functionWithIndex;
            this.val$function = functionWithIndex;
        }

        @Override // java.util.function.Consumer
        public void accept(@NullableDecl T t) {
            this.holder = t;
        }

        /* JADX WARN: Multi-variable type inference failed */
        @Override // java.util.Spliterator
        public boolean tryAdvance(Consumer<? super R> consumer) {
            if (this.fromSpliterator.tryAdvance(this)) {
                try {
                    FunctionWithIndex functionWithIndex = this.val$function;
                    T t = this.holder;
                    long j = this.index;
                    this.index = 1 + j;
                    consumer.accept(functionWithIndex.apply(t, j));
                    return true;
                } finally {
                    this.holder = null;
                }
            }
            return false;
        }

        /* JADX INFO: Access modifiers changed from: package-private */
        /* JADX WARN: Can't rename method to resolve collision */
        @Override // com.google.common.collect.Streams.MapWithIndexSpliterator
        public C1Splitr createSplit(Spliterator<T> spliterator, long j) {
            return new C1Splitr(spliterator, j, this.val$function);
        }
    }

    public static <R> Stream<R> mapWithIndex(final IntStream intStream, final IntFunctionWithIndex<R> intFunctionWithIndex) {
        Preconditions.checkNotNull(intStream);
        Preconditions.checkNotNull(intFunctionWithIndex);
        boolean isParallel = intStream.isParallel();
        Spliterator.OfInt spliterator = intStream.spliterator();
        if (!spliterator.hasCharacteristics(16384)) {
            final PrimitiveIterator.OfInt it = Spliterators.iterator(spliterator);
            Stream stream = StreamSupport.stream(new Spliterators.AbstractSpliterator<R>(spliterator.estimateSize(), spliterator.characteristics() & 80) { // from class: com.google.common.collect.Streams.3
                long index = 0;

                @Override // java.util.Spliterator
                public boolean tryAdvance(Consumer<? super R> consumer) {
                    if (it.hasNext()) {
                        IntFunctionWithIndex intFunctionWithIndex2 = intFunctionWithIndex;
                        int nextInt = it.nextInt();
                        long j = this.index;
                        this.index = 1 + j;
                        consumer.accept(intFunctionWithIndex2.apply(nextInt, j));
                        return true;
                    }
                    return false;
                }
            }, isParallel);
            intStream.getClass();
            return (Stream) stream.onClose(new Runnable() { // from class: com.google.common.collect.-$$Lambda$M_9LS_7GbvWBZmrlfKOp3wKwBM0
                @Override // java.lang.Runnable
                public final void run() {
                    intStream.close();
                }
            });
        }
        Stream stream2 = StreamSupport.stream(new C2Splitr(spliterator, 0L, intFunctionWithIndex), isParallel);
        intStream.getClass();
        return (Stream) stream2.onClose(new Runnable() { // from class: com.google.common.collect.-$$Lambda$M_9LS_7GbvWBZmrlfKOp3wKwBM0
            @Override // java.lang.Runnable
            public final void run() {
                intStream.close();
            }
        });
    }

    /* renamed from: com.google.common.collect.Streams$2Splitr  reason: invalid class name */
    /* loaded from: classes.dex */
    class C2Splitr extends MapWithIndexSpliterator<Spliterator.OfInt, R, C2Splitr> implements IntConsumer, Spliterator<R> {
        int holder;
        final /* synthetic */ IntFunctionWithIndex val$function;

        /* JADX WARN: 'super' call moved to the top of the method (can break code semantics) */
        /* JADX WARN: Multi-variable type inference failed */
        /* JADX WARN: Not initialized variable reg: 4, insn: 0x0000: IPUT  (r4 I:com.google.common.collect.Streams$IntFunctionWithIndex), (r0 I:com.google.common.collect.Streams$2Splitr) com.google.common.collect.Streams.2Splitr.val$function com.google.common.collect.Streams$IntFunctionWithIndex, block:B:2:0x0000 */
        C2Splitr(Spliterator.OfInt ofInt, Spliterator.OfInt ofInt2, long j) {
            super(ofInt, ofInt2);
            IntFunctionWithIndex intFunctionWithIndex;
            this.val$function = intFunctionWithIndex;
        }

        @Override // java.util.function.IntConsumer
        public void accept(int i) {
            this.holder = i;
        }

        @Override // java.util.Spliterator
        public boolean tryAdvance(Consumer<? super R> consumer) {
            if (((Spliterator.OfInt) this.fromSpliterator).tryAdvance((IntConsumer) this)) {
                IntFunctionWithIndex intFunctionWithIndex = this.val$function;
                int i = this.holder;
                long j = this.index;
                this.index = 1 + j;
                consumer.accept(intFunctionWithIndex.apply(i, j));
                return true;
            }
            return false;
        }

        /* JADX INFO: Access modifiers changed from: package-private */
        @Override // com.google.common.collect.Streams.MapWithIndexSpliterator
        public C2Splitr createSplit(Spliterator.OfInt ofInt, long j) {
            return new C2Splitr(ofInt, j, this.val$function);
        }
    }

    public static <R> Stream<R> mapWithIndex(final LongStream longStream, final LongFunctionWithIndex<R> longFunctionWithIndex) {
        Preconditions.checkNotNull(longStream);
        Preconditions.checkNotNull(longFunctionWithIndex);
        boolean isParallel = longStream.isParallel();
        Spliterator.OfLong spliterator = longStream.spliterator();
        if (!spliterator.hasCharacteristics(16384)) {
            final PrimitiveIterator.OfLong it = Spliterators.iterator(spliterator);
            Stream stream = StreamSupport.stream(new Spliterators.AbstractSpliterator<R>(spliterator.estimateSize(), spliterator.characteristics() & 80) { // from class: com.google.common.collect.Streams.4
                long index = 0;

                @Override // java.util.Spliterator
                public boolean tryAdvance(Consumer<? super R> consumer) {
                    if (it.hasNext()) {
                        LongFunctionWithIndex longFunctionWithIndex2 = longFunctionWithIndex;
                        long nextLong = it.nextLong();
                        long j = this.index;
                        this.index = 1 + j;
                        consumer.accept(longFunctionWithIndex2.apply(nextLong, j));
                        return true;
                    }
                    return false;
                }
            }, isParallel);
            longStream.getClass();
            return (Stream) stream.onClose(new Runnable() { // from class: com.google.common.collect.-$$Lambda$y3UzC9Ucub3hbmrgNozGHDddSDo
                @Override // java.lang.Runnable
                public final void run() {
                    longStream.close();
                }
            });
        }
        Stream stream2 = StreamSupport.stream(new C3Splitr(spliterator, 0L, longFunctionWithIndex), isParallel);
        longStream.getClass();
        return (Stream) stream2.onClose(new Runnable() { // from class: com.google.common.collect.-$$Lambda$y3UzC9Ucub3hbmrgNozGHDddSDo
            @Override // java.lang.Runnable
            public final void run() {
                longStream.close();
            }
        });
    }

    /* renamed from: com.google.common.collect.Streams$3Splitr  reason: invalid class name */
    /* loaded from: classes.dex */
    class C3Splitr extends MapWithIndexSpliterator<Spliterator.OfLong, R, C3Splitr> implements LongConsumer, Spliterator<R> {
        long holder;
        final /* synthetic */ LongFunctionWithIndex val$function;

        /* JADX WARN: 'super' call moved to the top of the method (can break code semantics) */
        /* JADX WARN: Multi-variable type inference failed */
        /* JADX WARN: Not initialized variable reg: 4, insn: 0x0000: IPUT  (r4 I:com.google.common.collect.Streams$LongFunctionWithIndex), (r0 I:com.google.common.collect.Streams$3Splitr) com.google.common.collect.Streams.3Splitr.val$function com.google.common.collect.Streams$LongFunctionWithIndex, block:B:2:0x0000 */
        C3Splitr(Spliterator.OfLong ofLong, Spliterator.OfLong ofLong2, long j) {
            super(ofLong, ofLong2);
            LongFunctionWithIndex longFunctionWithIndex;
            this.val$function = longFunctionWithIndex;
        }

        @Override // java.util.function.LongConsumer
        public void accept(long j) {
            this.holder = j;
        }

        @Override // java.util.Spliterator
        public boolean tryAdvance(Consumer<? super R> consumer) {
            if (((Spliterator.OfLong) this.fromSpliterator).tryAdvance((LongConsumer) this)) {
                LongFunctionWithIndex longFunctionWithIndex = this.val$function;
                long j = this.holder;
                long j2 = this.index;
                this.index = 1 + j2;
                consumer.accept(longFunctionWithIndex.apply(j, j2));
                return true;
            }
            return false;
        }

        /* JADX INFO: Access modifiers changed from: package-private */
        @Override // com.google.common.collect.Streams.MapWithIndexSpliterator
        public C3Splitr createSplit(Spliterator.OfLong ofLong, long j) {
            return new C3Splitr(ofLong, j, this.val$function);
        }
    }

    public static <R> Stream<R> mapWithIndex(final DoubleStream doubleStream, final DoubleFunctionWithIndex<R> doubleFunctionWithIndex) {
        Preconditions.checkNotNull(doubleStream);
        Preconditions.checkNotNull(doubleFunctionWithIndex);
        boolean isParallel = doubleStream.isParallel();
        Spliterator.OfDouble spliterator = doubleStream.spliterator();
        if (!spliterator.hasCharacteristics(16384)) {
            final PrimitiveIterator.OfDouble it = Spliterators.iterator(spliterator);
            Stream stream = StreamSupport.stream(new Spliterators.AbstractSpliterator<R>(spliterator.estimateSize(), spliterator.characteristics() & 80) { // from class: com.google.common.collect.Streams.5
                long index = 0;

                @Override // java.util.Spliterator
                public boolean tryAdvance(Consumer<? super R> consumer) {
                    if (it.hasNext()) {
                        DoubleFunctionWithIndex doubleFunctionWithIndex2 = doubleFunctionWithIndex;
                        double nextDouble = it.nextDouble();
                        long j = this.index;
                        this.index = 1 + j;
                        consumer.accept(doubleFunctionWithIndex2.apply(nextDouble, j));
                        return true;
                    }
                    return false;
                }
            }, isParallel);
            doubleStream.getClass();
            return (Stream) stream.onClose(new Runnable() { // from class: com.google.common.collect.-$$Lambda$GBpOF54sAws-PHwS5bXxRWrL0gU
                @Override // java.lang.Runnable
                public final void run() {
                    doubleStream.close();
                }
            });
        }
        Stream stream2 = StreamSupport.stream(new C4Splitr(spliterator, 0L, doubleFunctionWithIndex), isParallel);
        doubleStream.getClass();
        return (Stream) stream2.onClose(new Runnable() { // from class: com.google.common.collect.-$$Lambda$GBpOF54sAws-PHwS5bXxRWrL0gU
            @Override // java.lang.Runnable
            public final void run() {
                doubleStream.close();
            }
        });
    }

    /* renamed from: com.google.common.collect.Streams$4Splitr  reason: invalid class name */
    /* loaded from: classes.dex */
    class C4Splitr extends MapWithIndexSpliterator<Spliterator.OfDouble, R, C4Splitr> implements DoubleConsumer, Spliterator<R> {
        double holder;
        final /* synthetic */ DoubleFunctionWithIndex val$function;

        /* JADX WARN: 'super' call moved to the top of the method (can break code semantics) */
        /* JADX WARN: Multi-variable type inference failed */
        /* JADX WARN: Not initialized variable reg: 4, insn: 0x0000: IPUT  (r4 I:com.google.common.collect.Streams$DoubleFunctionWithIndex), (r0 I:com.google.common.collect.Streams$4Splitr) com.google.common.collect.Streams.4Splitr.val$function com.google.common.collect.Streams$DoubleFunctionWithIndex, block:B:2:0x0000 */
        C4Splitr(Spliterator.OfDouble ofDouble, Spliterator.OfDouble ofDouble2, long j) {
            super(ofDouble, ofDouble2);
            DoubleFunctionWithIndex doubleFunctionWithIndex;
            this.val$function = doubleFunctionWithIndex;
        }

        @Override // java.util.function.DoubleConsumer
        public void accept(double d) {
            this.holder = d;
        }

        @Override // java.util.Spliterator
        public boolean tryAdvance(Consumer<? super R> consumer) {
            if (((Spliterator.OfDouble) this.fromSpliterator).tryAdvance((DoubleConsumer) this)) {
                DoubleFunctionWithIndex doubleFunctionWithIndex = this.val$function;
                double d = this.holder;
                long j = this.index;
                this.index = 1 + j;
                consumer.accept(doubleFunctionWithIndex.apply(d, j));
                return true;
            }
            return false;
        }

        /* JADX INFO: Access modifiers changed from: package-private */
        @Override // com.google.common.collect.Streams.MapWithIndexSpliterator
        public C4Splitr createSplit(Spliterator.OfDouble ofDouble, long j) {
            return new C4Splitr(ofDouble, j, this.val$function);
        }
    }

    /* loaded from: classes.dex */
    private static abstract class MapWithIndexSpliterator<F extends Spliterator<?>, R, S extends MapWithIndexSpliterator<F, R, S>> implements Spliterator<R> {
        final F fromSpliterator;
        long index;

        abstract S createSplit(F f, long j);

        MapWithIndexSpliterator(F f, long j) {
            this.fromSpliterator = f;
            this.index = j;
        }

        /* JADX WARN: Multi-variable type inference failed */
        @Override // java.util.Spliterator
        public S trySplit() {
            Spliterator trySplit = this.fromSpliterator.trySplit();
            if (trySplit == null) {
                return null;
            }
            S s = (S) createSplit(trySplit, this.index);
            this.index += trySplit.getExactSizeIfKnown();
            return s;
        }

        @Override // java.util.Spliterator
        public long estimateSize() {
            return this.fromSpliterator.estimateSize();
        }

        @Override // java.util.Spliterator
        public int characteristics() {
            return this.fromSpliterator.characteristics() & 16464;
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    /* renamed from: com.google.common.collect.Streams$1OptionalState  reason: invalid class name */
    /* loaded from: classes.dex */
    public class C1OptionalState {
        boolean set = false;
        T value = null;

        C1OptionalState() {
        }

        /* JADX INFO: Access modifiers changed from: package-private */
        public void set(@NullableDecl T t) {
            this.set = true;
            this.value = t;
        }

        T get() {
            Preconditions.checkState(this.set);
            return this.value;
        }
    }

    public static <T> java.util.Optional<T> findLast(Stream<T> stream) {
        final C1OptionalState c1OptionalState = new C1OptionalState();
        ArrayDeque arrayDeque = new ArrayDeque();
        arrayDeque.addLast(stream.spliterator());
        while (!arrayDeque.isEmpty()) {
            Spliterator<T> spliterator = (Spliterator) arrayDeque.removeLast();
            if (spliterator.getExactSizeIfKnown() != 0) {
                if (spliterator.hasCharacteristics(16384)) {
                    while (true) {
                        Spliterator<T> trySplit = spliterator.trySplit();
                        if (trySplit != null && trySplit.getExactSizeIfKnown() != 0) {
                            if (spliterator.getExactSizeIfKnown() == 0) {
                                spliterator = trySplit;
                                break;
                            }
                        } else {
                            break;
                        }
                    }
                    c1OptionalState.getClass();
                    spliterator.forEachRemaining(new Consumer() { // from class: com.google.common.collect.-$$Lambda$FdgNCSLr1Jyf_TTg4Zv1xfQXf18
                        @Override // java.util.function.Consumer
                        public final void accept(Object obj) {
                            Streams.C1OptionalState.this.set(obj);
                        }
                    });
                    return java.util.Optional.of(c1OptionalState.get());
                }
                Spliterator<T> trySplit2 = spliterator.trySplit();
                if (trySplit2 == null || trySplit2.getExactSizeIfKnown() == 0) {
                    c1OptionalState.getClass();
                    spliterator.forEachRemaining(new Consumer() { // from class: com.google.common.collect.-$$Lambda$FdgNCSLr1Jyf_TTg4Zv1xfQXf18
                        @Override // java.util.function.Consumer
                        public final void accept(Object obj) {
                            Streams.C1OptionalState.this.set(obj);
                        }
                    });
                    if (c1OptionalState.set) {
                        return java.util.Optional.of(c1OptionalState.get());
                    }
                } else {
                    arrayDeque.addLast(trySplit2);
                    arrayDeque.addLast(spliterator);
                }
            }
        }
        return java.util.Optional.empty();
    }

    public static OptionalInt findLast(IntStream intStream) {
        java.util.Optional findLast = findLast(intStream.boxed());
        return findLast.isPresent() ? OptionalInt.of(((Integer) findLast.get()).intValue()) : OptionalInt.empty();
    }

    public static OptionalLong findLast(LongStream longStream) {
        java.util.Optional findLast = findLast(longStream.boxed());
        return findLast.isPresent() ? OptionalLong.of(((Long) findLast.get()).longValue()) : OptionalLong.empty();
    }

    public static OptionalDouble findLast(DoubleStream doubleStream) {
        java.util.Optional findLast = findLast(doubleStream.boxed());
        return findLast.isPresent() ? OptionalDouble.of(((Double) findLast.get()).doubleValue()) : OptionalDouble.empty();
    }

    private Streams() {
    }
}
