package com.google.common.util.concurrent;

import com.google.common.annotations.GwtCompatible;
import java.util.concurrent.atomic.AtomicReference;
import org.checkerframework.checker.nullness.compatqual.NullableDecl;
@GwtCompatible(emulated = true)
/* loaded from: classes.dex */
abstract class InterruptibleTask<T> extends AtomicReference<Runnable> implements Runnable {
    private static final Runnable DONE = new DoNothingRunnable();
    private static final Runnable INTERRUPTING = new DoNothingRunnable();

    abstract void afterRanInterruptibly(@NullableDecl T t, @NullableDecl Throwable th);

    abstract boolean isDone();

    abstract T runInterruptibly() throws Exception;

    abstract String toPendingString();

    /* loaded from: classes.dex */
    private static final class DoNothingRunnable implements Runnable {
        @Override // java.lang.Runnable
        public void run() {
        }

        private DoNothingRunnable() {
        }
    }

    /*  JADX ERROR: JadxRuntimeException in pass: BlockProcessor
        jadx.core.utils.exceptions.JadxRuntimeException: Found unreachable blocks
        	at jadx.core.dex.visitors.blocks.DominatorTree.sortBlocks(DominatorTree.java:35)
        	at jadx.core.dex.visitors.blocks.DominatorTree.compute(DominatorTree.java:25)
        	at jadx.core.dex.visitors.blocks.BlockProcessor.computeDominators(BlockProcessor.java:202)
        	at jadx.core.dex.visitors.blocks.BlockProcessor.processBlocksTree(BlockProcessor.java:45)
        	at jadx.core.dex.visitors.blocks.BlockProcessor.visit(BlockProcessor.java:39)
        */
    @Override // java.lang.Runnable
    public final void run() {
        /*
            r5 = this;
            java.lang.Thread r0 = java.lang.Thread.currentThread()
            r1 = 0
            boolean r2 = r5.compareAndSet(r1, r0)
            if (r2 != 0) goto Lc
            return
        Lc:
            boolean r2 = r5.isDone()
            r2 = r2 ^ 1
            if (r2 == 0) goto L4f
            java.lang.Object r3 = r5.runInterruptibly()     // Catch: java.lang.Throwable -> L34
            goto L50
        L19:
            r3 = move-exception
            java.lang.Runnable r4 = com.google.common.util.concurrent.InterruptibleTask.DONE
            boolean r0 = r5.compareAndSet(r0, r4)
            if (r0 != 0) goto L2e
        L22:
            java.lang.Object r0 = r5.get()
            java.lang.Runnable r4 = com.google.common.util.concurrent.InterruptibleTask.INTERRUPTING
            if (r0 != r4) goto L2e
            java.lang.Thread.yield()
            goto L22
        L2e:
            if (r2 == 0) goto L33
            r5.afterRanInterruptibly(r1, r1)
        L33:
            throw r3
        L34:
            r3 = move-exception
            java.lang.Runnable r4 = com.google.common.util.concurrent.InterruptibleTask.DONE
            boolean r0 = r5.compareAndSet(r0, r4)
            if (r0 != 0) goto L49
        L3d:
            java.lang.Object r0 = r5.get()
            java.lang.Runnable r4 = com.google.common.util.concurrent.InterruptibleTask.INTERRUPTING
            if (r0 != r4) goto L49
            java.lang.Thread.yield()
            goto L3d
        L49:
            if (r2 == 0) goto L69
            r5.afterRanInterruptibly(r1, r3)
            goto L69
        L4f:
            r3 = r1
        L50:
            java.lang.Runnable r4 = com.google.common.util.concurrent.InterruptibleTask.DONE
            boolean r0 = r5.compareAndSet(r0, r4)
            if (r0 != 0) goto L64
        L58:
            java.lang.Object r0 = r5.get()
            java.lang.Runnable r4 = com.google.common.util.concurrent.InterruptibleTask.INTERRUPTING
            if (r0 != r4) goto L64
            java.lang.Thread.yield()
            goto L58
        L64:
            if (r2 == 0) goto L69
            r5.afterRanInterruptibly(r3, r1)
        L69:
            return
        */
        throw new UnsupportedOperationException("Method not decompiled: com.google.common.util.concurrent.InterruptibleTask.run():void");
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public final void interruptTask() {
        Runnable runnable = get();
        if ((runnable instanceof Thread) && compareAndSet(runnable, INTERRUPTING)) {
            ((Thread) runnable).interrupt();
            set(DONE);
        }
    }

    @Override // java.util.concurrent.atomic.AtomicReference
    public final String toString() {
        String str;
        Runnable runnable = get();
        if (runnable == DONE) {
            str = "running=[DONE]";
        } else if (runnable == INTERRUPTING) {
            str = "running=[INTERRUPTED]";
        } else if (runnable instanceof Thread) {
            str = "running=[RUNNING ON " + ((Thread) runnable).getName() + "]";
        } else {
            str = "running=[NOT STARTED YET]";
        }
        return str + ", " + toPendingString();
    }
}
