package com.google.firebase.crashlytics.buildtools;

import com.google.firebase.crashlytics.buildtools.Obfuscator;
import com.google.firebase.crashlytics.buildtools.log.CrashlyticsLogger;
import com.google.firebase.crashlytics.buildtools.utils.FileUtils;
import com.google.firebase.crashlytics.buildtools.utils.PropertiesUtils;
import java.io.File;
import java.io.IOException;
import java.util.Properties;
import org.apache.commons.io.IOUtils;
/* loaded from: classes.dex */
public class CommandLineHelper {
    private static final String[] VALID_COMMANDS = {"help", CrashlyticsOptions.OPT_INJECT_MAPPING_FILE_ID, CrashlyticsOptions.OPT_UPLOAD_MAPPING_FILE, CrashlyticsOptions.OPT_GENERATE_NATIVE_SYMBOLS, CrashlyticsOptions.OPT_UPLOAD_NATIVE_SYMBOLS};
    private final Properties cliArgs;

    public static void main(String[] strArr) {
        try {
            Buildtools.getLogger();
            int length = strArr.length;
            boolean z = false;
            int i = 0;
            boolean z2 = false;
            while (true) {
                if (i >= length) {
                    break;
                }
                String str = strArr[i];
                if (str.equals("-verbose")) {
                    z = true;
                    break;
                }
                if (str.equals("-quiet")) {
                    z2 = true;
                }
                i++;
            }
            if (z) {
                Buildtools.getLogger().setLevel(CrashlyticsLogger.Level.VERBOSE);
            } else if (z2) {
                Buildtools.getLogger().setLevel(CrashlyticsLogger.Level.ERROR);
            }
            Properties processArgs = PropertiesUtils.processArgs(CommandLineHelper.class.getName(), strArr, CrashlyticsOptions.createOptions());
            Buildtools.logD("Invoked Crashlytics Buildtools with arguments: " + PropertiesUtils.toString(processArgs).replaceAll(IOUtils.LINE_SEPARATOR_UNIX, "\n\t"));
            new CommandLineHelper(processArgs).doMain();
        } catch (Exception e) {
            Buildtools.logE(e.getMessage(), e);
        }
    }

    public CommandLineHelper(Properties properties) {
        this.cliArgs = properties;
    }

    public void configureWebApi() {
        Buildtools.setWebApi(Buildtools.createWebApi());
        Package r0 = CommandLineHelper.class.getPackage();
        Buildtools.getInstance().setBuildtoolsClientInfo(r0.getImplementationTitle(), r0.getImplementationVersion());
    }

    private void doMain() throws IOException {
        configureWebApi();
        int i = 0;
        for (String str : VALID_COMMANDS) {
            if (this.cliArgs.containsKey(str)) {
                i++;
            }
        }
        if (i != 1) {
            throw new IllegalArgumentException("Exactly ONE valid command required. Use '-help' valid arguments.");
        }
        if (this.cliArgs.containsKey(CrashlyticsOptions.OPT_INJECT_MAPPING_FILE_ID)) {
            executeInjectMappingFileId();
        } else if (this.cliArgs.containsKey(CrashlyticsOptions.OPT_UPLOAD_MAPPING_FILE)) {
            executeUploadMappingFile();
        } else if (this.cliArgs.containsKey(CrashlyticsOptions.OPT_GENERATE_NATIVE_SYMBOLS)) {
            executeGenerateSymbols();
        } else if (this.cliArgs.containsKey(CrashlyticsOptions.OPT_UPLOAD_NATIVE_SYMBOLS)) {
            executeUploadSymbols();
        }
    }

    private void executeInjectMappingFileId() throws IOException {
        String propertyOrThrow = getPropertyOrThrow(this.cliArgs, CrashlyticsOptions.OPT_INJECT_MAPPING_FILE_ID);
        Buildtools.getInstance().injectMappingFileIdIntoResource(new File(propertyOrThrow), getPropertyOrThrow(this.cliArgs, CrashlyticsOptions.OPT_MAPPING_FILE_ID));
    }

    private void executeUploadMappingFile() throws IOException {
        String propertyOrThrow = getPropertyOrThrow(this.cliArgs, CrashlyticsOptions.OPT_UPLOAD_MAPPING_FILE);
        Buildtools.getInstance().uploadMappingFile(new File(propertyOrThrow), getPropertyOrThrow(this.cliArgs, CrashlyticsOptions.OPT_MAPPING_FILE_ID), new AppBuildInfo(getPropertyOrThrow(this.cliArgs, CrashlyticsOptions.OPT_ANDROID_APPLICATION_ID), getPropertyOrThrow(this.cliArgs, CrashlyticsOptions.OPT_GOOGLE_APP_ID), null), new Obfuscator(Obfuscator.Vendor.PROGUARD, "0.0.0"));
    }

    private void executeGenerateSymbols() throws IOException {
        String property = this.cliArgs.getProperty(CrashlyticsOptions.OPT_NATIVE_UNSTRIPPED_LIB);
        String property2 = this.cliArgs.getProperty(CrashlyticsOptions.OPT_NATIVE_UNSTRIPPED_LIBS_DIR);
        boolean z = property != null;
        if (!Boolean.logicalXor(z, property2 != null)) {
            throw new IllegalArgumentException("generateNativeSymbols requires either 1) unstrippedLibrary or 2) unstrippedLibrariesDir");
        }
        File file = new File(getPropertyOrThrow(this.cliArgs, CrashlyticsOptions.OPT_CSYM_CACHE_DIR));
        FileUtils.verifyDirectory(file);
        Buildtools.getInstance().generateNativeSymbolFiles(z ? new File(property) : new File(property2), file);
    }

    private void executeUploadSymbols() throws IOException {
        File file = new File(getPropertyOrThrow(this.cliArgs, CrashlyticsOptions.OPT_CSYM_CACHE_DIR));
        FileUtils.verifyDirectory(file);
        Buildtools.getInstance().uploadNativeSymbolFiles(file, getPropertyOrThrow(this.cliArgs, CrashlyticsOptions.OPT_GOOGLE_APP_ID));
    }

    private static String getPropertyOrThrow(Properties properties, String str) throws IllegalArgumentException {
        String property = properties.getProperty(str);
        if (property != null) {
            return property;
        }
        throw new IllegalArgumentException("Required argument missing: " + str);
    }
}
