package com.loopj.android.http;

import com.google.common.base.Ascii;
import com.google.common.primitives.UnsignedBytes;
import java.io.UnsupportedEncodingException;
/* loaded from: classes.dex */
public class Base64 {
    public static final int CRLF = 4;
    public static final int DEFAULT = 0;
    public static final int NO_CLOSE = 16;
    public static final int NO_PADDING = 1;
    public static final int NO_WRAP = 2;
    public static final int URL_SAFE = 8;

    private Base64() {
    }

    public static byte[] decode(String str, int i) {
        return decode(str.getBytes(), i);
    }

    public static byte[] decode(byte[] bArr, int i) {
        return decode(bArr, 0, bArr.length, i);
    }

    public static byte[] decode(byte[] bArr, int i, int i2, int i3) {
        Decoder decoder = new Decoder(i3, new byte[(i2 * 3) / 4]);
        if (!decoder.process(bArr, i, i2, true)) {
            throw new IllegalArgumentException("bad base-64");
        }
        if (decoder.op == decoder.output.length) {
            return decoder.output;
        }
        byte[] bArr2 = new byte[decoder.op];
        System.arraycopy(decoder.output, 0, bArr2, 0, decoder.op);
        return bArr2;
    }

    public static String encodeToString(byte[] bArr, int i) {
        try {
            return new String(encode(bArr, i), "US-ASCII");
        } catch (UnsupportedEncodingException e) {
            throw new AssertionError(e);
        }
    }

    public static String encodeToString(byte[] bArr, int i, int i2, int i3) {
        try {
            return new String(encode(bArr, i, i2, i3), "US-ASCII");
        } catch (UnsupportedEncodingException e) {
            throw new AssertionError(e);
        }
    }

    public static byte[] encode(byte[] bArr, int i) {
        return encode(bArr, 0, bArr.length, i);
    }

    public static byte[] encode(byte[] bArr, int i, int i2, int i3) {
        Encoder encoder = new Encoder(i3, null);
        int i4 = (i2 / 3) * 4;
        if (!encoder.do_padding) {
            switch (i2 % 3) {
                case 1:
                    i4 += 2;
                    break;
                case 2:
                    i4 += 3;
                    break;
            }
        } else if (i2 % 3 > 0) {
            i4 += 4;
        }
        if (encoder.do_newline && i2 > 0) {
            i4 += (((i2 - 1) / 57) + 1) * (encoder.do_cr ? 2 : 1);
        }
        encoder.output = new byte[i4];
        encoder.process(bArr, i, i2, true);
        return encoder.output;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    /* loaded from: classes.dex */
    public static abstract class Coder {
        public int op;
        public byte[] output;

        public abstract int maxOutputSize(int i);

        public abstract boolean process(byte[] bArr, int i, int i2, boolean z);

        Coder() {
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    /* loaded from: classes.dex */
    public static class Decoder extends Coder {
        private static final int[] DECODE = {-1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, 62, -1, -1, -1, 63, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, -1, -1, -1, -2, -1, -1, -1, 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, -1, -1, -1, -1, -1, -1, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1};
        private static final int[] DECODE_WEBSAFE = {-1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, 62, -1, -1, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, -1, -1, -1, -2, -1, -1, -1, 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, -1, -1, -1, -1, 63, -1, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1};
        private static final int EQUALS = -2;
        private static final int SKIP = -1;
        private final int[] alphabet;
        private int state;
        private int value;

        public Decoder(int i, byte[] bArr) {
            this.output = bArr;
            this.alphabet = (i & 8) == 0 ? DECODE : DECODE_WEBSAFE;
            this.state = 0;
            this.value = 0;
        }

        @Override // com.loopj.android.http.Base64.Coder
        public int maxOutputSize(int i) {
            return ((i * 3) / 4) + 10;
        }

        /* JADX WARN: Removed duplicated region for block: B:55:0x00e6  */
        /* JADX WARN: Removed duplicated region for block: B:57:0x00ed  */
        @Override // com.loopj.android.http.Base64.Coder
        /*
            Code decompiled incorrectly, please refer to instructions dump.
        */
        public boolean process(byte[] bArr, int i, int i2, boolean z) {
            if (this.state == 6) {
                return false;
            }
            int i3 = i2 + i;
            int i4 = this.state;
            int i5 = this.value;
            byte[] bArr2 = this.output;
            int[] iArr = this.alphabet;
            int i6 = i5;
            int i7 = 0;
            while (i < i3) {
                if (i4 == 0) {
                    while (true) {
                        int i8 = i + 4;
                        if (i8 <= i3 && (i6 = (iArr[bArr[i] & UnsignedBytes.MAX_VALUE] << 18) | (iArr[bArr[i + 1] & UnsignedBytes.MAX_VALUE] << 12) | (iArr[bArr[i + 2] & UnsignedBytes.MAX_VALUE] << 6) | iArr[bArr[i + 3] & UnsignedBytes.MAX_VALUE]) >= 0) {
                            bArr2[i7 + 2] = (byte) i6;
                            bArr2[i7 + 1] = (byte) (i6 >> 8);
                            bArr2[i7] = (byte) (i6 >> 16);
                            i7 += 3;
                            i = i8;
                        }
                    }
                    if (i >= i3) {
                        if (z) {
                            this.state = i4;
                            this.value = i6;
                            this.op = i7;
                            return true;
                        }
                        switch (i4) {
                            case 1:
                                this.state = 6;
                                return false;
                            case 2:
                                bArr2[i7] = (byte) (i6 >> 4);
                                i7++;
                                break;
                            case 3:
                                int i9 = i7 + 1;
                                bArr2[i7] = (byte) (i6 >> 10);
                                i7 = i9 + 1;
                                bArr2[i9] = (byte) (i6 >> 2);
                                break;
                            case 4:
                                this.state = 6;
                                return false;
                        }
                        this.state = i4;
                        this.op = i7;
                        return true;
                    }
                }
                int i10 = i + 1;
                int i11 = iArr[bArr[i] & UnsignedBytes.MAX_VALUE];
                switch (i4) {
                    case 0:
                        if (i11 >= 0) {
                            i4++;
                            break;
                        } else if (i11 != -1) {
                            this.state = 6;
                            return false;
                        } else {
                            continue;
                            i = i10;
                        }
                    case 1:
                        if (i11 >= 0) {
                            i11 |= i6 << 6;
                            i4++;
                            break;
                        } else if (i11 != -1) {
                            this.state = 6;
                            return false;
                        } else {
                            continue;
                            i = i10;
                        }
                    case 2:
                        if (i11 >= 0) {
                            i11 |= i6 << 6;
                            i4++;
                            break;
                        } else {
                            if (i11 == -2) {
                                bArr2[i7] = (byte) (i6 >> 4);
                                i7++;
                                i4 = 4;
                                continue;
                            } else if (i11 != -1) {
                                this.state = 6;
                                return false;
                            }
                            i = i10;
                        }
                    case 3:
                        if (i11 >= 0) {
                            int i12 = i11 | (i6 << 6);
                            bArr2[i7 + 2] = (byte) i12;
                            bArr2[i7 + 1] = (byte) (i12 >> 8);
                            bArr2[i7] = (byte) (i12 >> 16);
                            i7 += 3;
                            i6 = i12;
                            i4 = 0;
                            continue;
                        } else if (i11 == -2) {
                            bArr2[i7 + 1] = (byte) (i6 >> 2);
                            bArr2[i7] = (byte) (i6 >> 10);
                            i7 += 2;
                            i4 = 5;
                        } else if (i11 != -1) {
                            this.state = 6;
                            return false;
                        }
                        i = i10;
                    case 4:
                        if (i11 == -2) {
                            i4++;
                            continue;
                        } else if (i11 != -1) {
                            this.state = 6;
                            return false;
                        }
                        i = i10;
                    case 5:
                        if (i11 != -1) {
                            this.state = 6;
                            return false;
                        }
                        continue;
                        i = i10;
                    default:
                        i = i10;
                }
                i6 = i11;
                i = i10;
            }
            if (z) {
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    /* loaded from: classes.dex */
    public static class Encoder extends Coder {
        private static final byte[] ENCODE = {65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 43, 47};
        private static final byte[] ENCODE_WEBSAFE = {65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 45, 95};
        public static final int LINE_GROUPS = 19;
        private final byte[] alphabet;
        private int count;
        public final boolean do_cr;
        public final boolean do_newline;
        public final boolean do_padding;
        private final byte[] tail;
        int tailLen;

        public Encoder(int i, byte[] bArr) {
            this.output = bArr;
            this.do_padding = (i & 1) == 0;
            this.do_newline = (i & 2) == 0;
            this.do_cr = (i & 4) != 0;
            this.alphabet = (i & 8) == 0 ? ENCODE : ENCODE_WEBSAFE;
            this.tail = new byte[2];
            this.tailLen = 0;
            this.count = this.do_newline ? 19 : -1;
        }

        @Override // com.loopj.android.http.Base64.Coder
        public int maxOutputSize(int i) {
            return ((i * 8) / 5) + 10;
        }

        /* JADX WARN: Can't fix incorrect switch cases order, some code will duplicate */
        @Override // com.loopj.android.http.Base64.Coder
        public boolean process(byte[] bArr, int i, int i2, boolean z) {
            int i3;
            int i4;
            int i5;
            int i6;
            boolean z2;
            int i7;
            byte b;
            byte b2;
            int i8;
            int i9;
            int i10;
            byte b3;
            int i11;
            int i12;
            int i13;
            byte[] bArr2 = this.alphabet;
            byte[] bArr3 = this.output;
            int i14 = this.count;
            int i15 = i2 + i;
            int i16 = 0;
            switch (this.tailLen) {
                case 0:
                default:
                    i3 = i;
                    i4 = -1;
                    break;
                case 1:
                    if (i + 2 <= i15) {
                        int i17 = i + 1;
                        i3 = i17 + 1;
                        i4 = ((bArr[i] & UnsignedBytes.MAX_VALUE) << 8) | ((this.tail[0] & UnsignedBytes.MAX_VALUE) << 16) | (bArr[i17] & UnsignedBytes.MAX_VALUE);
                        this.tailLen = 0;
                        break;
                    }
                    i3 = i;
                    i4 = -1;
                    break;
                case 2:
                    i3 = i + 1;
                    if (i3 <= i15) {
                        i4 = (bArr[i] & UnsignedBytes.MAX_VALUE) | ((this.tail[0] & UnsignedBytes.MAX_VALUE) << 16) | ((this.tail[1] & UnsignedBytes.MAX_VALUE) << 8);
                        this.tailLen = 0;
                        break;
                    }
                    i3 = i;
                    i4 = -1;
                    break;
            }
            if (i4 != -1) {
                bArr3[0] = bArr2[(i4 >> 18) & 63];
                bArr3[1] = bArr2[(i4 >> 12) & 63];
                bArr3[2] = bArr2[(i4 >> 6) & 63];
                bArr3[3] = bArr2[i4 & 63];
                int i18 = i14 - 1;
                if (i18 == 0) {
                    if (this.do_cr) {
                        i13 = 5;
                        bArr3[4] = Ascii.CR;
                    } else {
                        i13 = 4;
                    }
                    i6 = i13 + 1;
                    bArr3[i13] = 10;
                    i5 = 19;
                } else {
                    i5 = i18;
                    i6 = 4;
                }
            } else {
                i5 = i14;
                i6 = 0;
            }
            while (true) {
                int i19 = i3 + 3;
                if (i19 <= i15) {
                    int i20 = (bArr[i3 + 2] & UnsignedBytes.MAX_VALUE) | ((bArr[i3 + 1] & UnsignedBytes.MAX_VALUE) << 8) | ((bArr[i3] & UnsignedBytes.MAX_VALUE) << 16);
                    bArr3[i6] = bArr2[(i20 >> 18) & 63];
                    bArr3[i6 + 1] = bArr2[(i20 >> 12) & 63];
                    bArr3[i6 + 2] = bArr2[(i20 >> 6) & 63];
                    bArr3[i6 + 3] = bArr2[i20 & 63];
                    i6 += 4;
                    i5--;
                    if (i5 == 0) {
                        if (this.do_cr) {
                            i12 = i6 + 1;
                            bArr3[i6] = Ascii.CR;
                        } else {
                            i12 = i6;
                        }
                        i6 = i12 + 1;
                        bArr3[i12] = 10;
                        i3 = i19;
                        i5 = 19;
                    } else {
                        i3 = i19;
                    }
                } else {
                    if (z) {
                        if (i3 - this.tailLen == i15 - 1) {
                            if (this.tailLen > 0) {
                                b3 = this.tail[0];
                                i16 = 1;
                            } else {
                                b3 = bArr[i3];
                            }
                            int i21 = (b3 & UnsignedBytes.MAX_VALUE) << 4;
                            this.tailLen -= i16;
                            int i22 = i6 + 1;
                            bArr3[i6] = bArr2[(i21 >> 6) & 63];
                            i6 = i22 + 1;
                            bArr3[i22] = bArr2[i21 & 63];
                            if (this.do_padding) {
                                int i23 = i6 + 1;
                                bArr3[i6] = 61;
                                i6 = i23 + 1;
                                bArr3[i23] = 61;
                            }
                            if (this.do_newline) {
                                if (this.do_cr) {
                                    i11 = i6 + 1;
                                    bArr3[i6] = Ascii.CR;
                                } else {
                                    i11 = i6;
                                }
                                i10 = i11 + 1;
                                bArr3[i11] = 10;
                                i6 = i10;
                            }
                        } else if (i3 - this.tailLen == i15 - 2) {
                            if (this.tailLen > 1) {
                                b = this.tail[0];
                                i16 = 1;
                            } else {
                                int i24 = i3 + 1;
                                byte b4 = bArr[i3];
                                i3 = i24;
                                b = b4;
                            }
                            int i25 = (b & UnsignedBytes.MAX_VALUE) << 10;
                            if (this.tailLen > 0) {
                                i8 = i16 + 1;
                                b2 = this.tail[i16];
                            } else {
                                b2 = bArr[i3];
                                i8 = i16;
                            }
                            int i26 = ((b2 & UnsignedBytes.MAX_VALUE) << 2) | i25;
                            this.tailLen -= i8;
                            int i27 = i6 + 1;
                            bArr3[i6] = bArr2[(i26 >> 12) & 63];
                            int i28 = i27 + 1;
                            bArr3[i27] = bArr2[(i26 >> 6) & 63];
                            int i29 = i28 + 1;
                            bArr3[i28] = bArr2[i26 & 63];
                            if (this.do_padding) {
                                i9 = i29 + 1;
                                bArr3[i29] = 61;
                            } else {
                                i9 = i29;
                            }
                            if (this.do_newline) {
                                if (this.do_cr) {
                                    bArr3[i9] = Ascii.CR;
                                    i9++;
                                }
                                i10 = i9 + 1;
                                bArr3[i9] = 10;
                                i6 = i10;
                            } else {
                                i6 = i9;
                            }
                        } else if (this.do_newline && i6 > 0 && i5 != 19) {
                            if (this.do_cr) {
                                i7 = i6 + 1;
                                bArr3[i6] = Ascii.CR;
                            } else {
                                i7 = i6;
                            }
                            i6 = i7 + 1;
                            bArr3[i7] = 10;
                        }
                        this.op = i6;
                        this.count = i5;
                        return z2;
                    } else if (i3 == i15 - 1) {
                        byte[] bArr4 = this.tail;
                        int i30 = this.tailLen;
                        this.tailLen = i30 + 1;
                        bArr4[i30] = bArr[i3];
                    } else if (i3 == i15 - 2) {
                        byte[] bArr5 = this.tail;
                        int i31 = this.tailLen;
                        this.tailLen = i31 + 1;
                        bArr5[i31] = bArr[i3];
                        byte[] bArr6 = this.tail;
                        int i32 = this.tailLen;
                        this.tailLen = i32 + 1;
                        z2 = true;
                        bArr6[i32] = bArr[i3 + 1];
                        this.op = i6;
                        this.count = i5;
                        return z2;
                    }
                    z2 = true;
                    this.op = i6;
                    this.count = i5;
                    return z2;
                }
            }
        }
    }
}
