package org.apache.commons.io.input;

import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.RandomAccessFile;
import java.nio.charset.Charset;
import org.apache.commons.io.FileUtils;
/* loaded from: classes.dex */
public class Tailer implements Runnable {
    private static final int DEFAULT_BUFSIZE = 4096;
    private static final Charset DEFAULT_CHARSET = Charset.defaultCharset();
    private static final int DEFAULT_DELAY_MILLIS = 1000;
    private static final String RAF_MODE = "r";
    private final Charset cset;
    private final long delayMillis;
    private final boolean end;
    private final File file;
    private final byte[] inbuf;
    private final TailerListener listener;
    private final boolean reOpen;
    private volatile boolean run;

    public Tailer(File file, TailerListener tailerListener) {
        this(file, tailerListener, 1000L);
    }

    public Tailer(File file, TailerListener tailerListener, long j) {
        this(file, tailerListener, j, false);
    }

    public Tailer(File file, TailerListener tailerListener, long j, boolean z) {
        this(file, tailerListener, j, z, 4096);
    }

    public Tailer(File file, TailerListener tailerListener, long j, boolean z, boolean z2) {
        this(file, tailerListener, j, z, z2, 4096);
    }

    public Tailer(File file, TailerListener tailerListener, long j, boolean z, int i) {
        this(file, tailerListener, j, z, false, i);
    }

    public Tailer(File file, TailerListener tailerListener, long j, boolean z, boolean z2, int i) {
        this(file, DEFAULT_CHARSET, tailerListener, j, z, z2, i);
    }

    public Tailer(File file, Charset charset, TailerListener tailerListener, long j, boolean z, boolean z2, int i) {
        this.run = true;
        this.file = file;
        this.delayMillis = j;
        this.end = z;
        this.inbuf = new byte[i];
        this.listener = tailerListener;
        tailerListener.init(this);
        this.reOpen = z2;
        this.cset = charset;
    }

    public static Tailer create(File file, TailerListener tailerListener, long j, boolean z, int i) {
        return create(file, tailerListener, j, z, false, i);
    }

    public static Tailer create(File file, TailerListener tailerListener, long j, boolean z, boolean z2, int i) {
        return create(file, DEFAULT_CHARSET, tailerListener, j, z, z2, i);
    }

    public static Tailer create(File file, Charset charset, TailerListener tailerListener, long j, boolean z, boolean z2, int i) {
        Tailer tailer = new Tailer(file, charset, tailerListener, j, z, z2, i);
        Thread thread = new Thread(tailer);
        thread.setDaemon(true);
        thread.start();
        return tailer;
    }

    public static Tailer create(File file, TailerListener tailerListener, long j, boolean z) {
        return create(file, tailerListener, j, z, 4096);
    }

    public static Tailer create(File file, TailerListener tailerListener, long j, boolean z, boolean z2) {
        return create(file, tailerListener, j, z, z2, 4096);
    }

    public static Tailer create(File file, TailerListener tailerListener, long j) {
        return create(file, tailerListener, j, false);
    }

    public static Tailer create(File file, TailerListener tailerListener) {
        return create(file, tailerListener, 1000L, false);
    }

    public File getFile() {
        return this.file;
    }

    protected boolean getRun() {
        return this.run;
    }

    public long getDelay() {
        return this.delayMillis;
    }

    /* JADX WARN: Removed duplicated region for block: B:111:0x0115 A[EXC_TOP_SPLITTER, SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:115:0x0132 A[EXC_TOP_SPLITTER, SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:128:0x013b A[EXC_TOP_SPLITTER, SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:50:0x0099  */
    @Override // java.lang.Runnable
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public void run() {
        RandomAccessFile randomAccessFile;
        RandomAccessFile randomAccessFile2;
        Throwable th;
        RandomAccessFile randomAccessFile3;
        RandomAccessFile randomAccessFile4 = null;
        long j = 0;
        long j2 = 0;
        while (getRun() && randomAccessFile4 == null) {
            try {
                try {
                    try {
                        randomAccessFile4 = new RandomAccessFile(this.file, RAF_MODE);
                    } catch (FileNotFoundException unused) {
                        this.listener.fileNotFound();
                    }
                    if (randomAccessFile4 == null) {
                        Thread.sleep(this.delayMillis);
                    } else {
                        j2 = this.end ? this.file.length() : 0L;
                        j = this.file.lastModified();
                        randomAccessFile4.seek(j2);
                    }
                } catch (Throwable th2) {
                    th = th2;
                }
            } catch (InterruptedException e) {
                e = e;
            } catch (Exception e2) {
                e = e2;
            }
        }
        while (getRun()) {
            boolean isFileNewer = FileUtils.isFileNewer(this.file, j);
            long length = this.file.length();
            if (length < j2) {
                this.listener.fileRotated();
                try {
                    randomAccessFile3 = new RandomAccessFile(this.file, RAF_MODE);
                    try {
                        try {
                            readLines(randomAccessFile4);
                        } catch (Throwable th3) {
                            randomAccessFile = randomAccessFile3;
                            th = th3;
                            try {
                                throw th;
                            } catch (Throwable th4) {
                                randomAccessFile2 = randomAccessFile;
                                th = th4;
                                try {
                                    if (randomAccessFile4 != null) {
                                        if (th != null) {
                                            try {
                                                randomAccessFile4.close();
                                            } catch (Throwable th5) {
                                                th.addSuppressed(th5);
                                            }
                                        } else {
                                            randomAccessFile4.close();
                                        }
                                    }
                                    throw th;
                                    break;
                                } catch (FileNotFoundException unused2) {
                                    randomAccessFile4 = randomAccessFile2;
                                    this.listener.fileNotFound();
                                    Thread.sleep(this.delayMillis);
                                } catch (InterruptedException e3) {
                                    e = e3;
                                    randomAccessFile4 = randomAccessFile2;
                                    Thread.currentThread().interrupt();
                                    this.listener.handle(e);
                                    if (randomAccessFile4 != null) {
                                    }
                                    stop();
                                } catch (Exception e4) {
                                    e = e4;
                                    randomAccessFile4 = randomAccessFile2;
                                    this.listener.handle(e);
                                    if (randomAccessFile4 != null) {
                                    }
                                    stop();
                                } catch (Throwable th6) {
                                    th = th6;
                                    randomAccessFile4 = randomAccessFile2;
                                    if (randomAccessFile4 != null) {
                                    }
                                    stop();
                                    throw th;
                                }
                            }
                        }
                    } catch (IOException e5) {
                        this.listener.handle(e5);
                    } catch (Throwable th7) {
                        th = th7;
                        randomAccessFile2 = randomAccessFile3;
                        th = null;
                        if (randomAccessFile4 != null) {
                        }
                        throw th;
                        break;
                        break;
                    }
                    if (randomAccessFile4 != null) {
                        try {
                            try {
                                randomAccessFile4.close();
                            } catch (FileNotFoundException unused3) {
                                j2 = 0;
                                randomAccessFile4 = randomAccessFile3;
                                this.listener.fileNotFound();
                                Thread.sleep(this.delayMillis);
                            }
                        } catch (InterruptedException e6) {
                            e = e6;
                            randomAccessFile4 = randomAccessFile3;
                            Thread.currentThread().interrupt();
                            this.listener.handle(e);
                            if (randomAccessFile4 != null) {
                                try {
                                    randomAccessFile4.close();
                                } catch (IOException e7) {
                                    e = e7;
                                    this.listener.handle(e);
                                    stop();
                                }
                            }
                            stop();
                        } catch (Exception e8) {
                            e = e8;
                            randomAccessFile4 = randomAccessFile3;
                            this.listener.handle(e);
                            if (randomAccessFile4 != null) {
                                try {
                                    randomAccessFile4.close();
                                } catch (IOException e9) {
                                    e = e9;
                                    this.listener.handle(e);
                                    stop();
                                }
                            }
                            stop();
                        } catch (Throwable th8) {
                            th = th8;
                            randomAccessFile4 = randomAccessFile3;
                            if (randomAccessFile4 != null) {
                                try {
                                    randomAccessFile4.close();
                                } catch (IOException e10) {
                                    this.listener.handle(e10);
                                }
                            }
                            stop();
                            throw th;
                        }
                    }
                    j2 = 0;
                    randomAccessFile4 = randomAccessFile3;
                } catch (Throwable th9) {
                    th = th9;
                    randomAccessFile = randomAccessFile4;
                }
            } else {
                if (length > j2) {
                    j2 = readLines(randomAccessFile4);
                    j = this.file.lastModified();
                } else if (isFileNewer) {
                    randomAccessFile4.seek(0L);
                    j2 = readLines(randomAccessFile4);
                    j = this.file.lastModified();
                }
                if (this.reOpen && randomAccessFile4 != null) {
                    randomAccessFile4.close();
                }
                Thread.sleep(this.delayMillis);
                if (getRun() && this.reOpen) {
                    randomAccessFile3 = new RandomAccessFile(this.file, RAF_MODE);
                    randomAccessFile3.seek(j2);
                    randomAccessFile4 = randomAccessFile3;
                }
            }
        }
        if (randomAccessFile4 != null) {
            try {
                randomAccessFile4.close();
            } catch (IOException e11) {
                e = e11;
                this.listener.handle(e);
                stop();
            }
        }
        stop();
    }

    public void stop() {
        this.run = false;
    }

    private long readLines(RandomAccessFile randomAccessFile) throws IOException {
        int read;
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream(64);
        try {
            long filePointer = randomAccessFile.getFilePointer();
            long j = filePointer;
            boolean z = false;
            while (getRun() && (read = randomAccessFile.read(this.inbuf)) != -1) {
                long j2 = filePointer;
                for (int i = 0; i < read; i++) {
                    byte b = this.inbuf[i];
                    if (b == 10) {
                        this.listener.handle(new String(byteArrayOutputStream.toByteArray(), this.cset));
                        byteArrayOutputStream.reset();
                        j2 = i + j + 1;
                        z = false;
                    } else if (b != 13) {
                        if (z) {
                            this.listener.handle(new String(byteArrayOutputStream.toByteArray(), this.cset));
                            byteArrayOutputStream.reset();
                            j2 = i + j + 1;
                            z = false;
                        }
                        byteArrayOutputStream.write(b);
                    } else {
                        if (z) {
                            byteArrayOutputStream.write(13);
                        }
                        z = true;
                    }
                }
                j = randomAccessFile.getFilePointer();
                filePointer = j2;
            }
            randomAccessFile.seek(filePointer);
            if (this.listener instanceof TailerListenerAdapter) {
                ((TailerListenerAdapter) this.listener).endOfFileReached();
            }
            byteArrayOutputStream.close();
            return filePointer;
        } catch (Throwable th) {
            try {
                throw th;
            } catch (Throwable th2) {
                if (th != null) {
                    try {
                        byteArrayOutputStream.close();
                    } catch (Throwable th3) {
                        th.addSuppressed(th3);
                    }
                } else {
                    byteArrayOutputStream.close();
                }
                throw th2;
            }
        }
    }
}
